@@ -1,7 +1,7 @@
 /* dummy-ups.h - NUT testing driver and repeater
 
    Copyright (C)
-       2005 - 2009  Arnaud Quette <http://arnaud.quette.free.fr/contact.html>
+       2005 - 2010  Arnaud Quette <http://arnaud.quette.free.fr/contact.html>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
  * as the "port" parameter (only the file name, not the path).
  * The format of this file is the same as an upsc dump:
  * <varname>: <value>
+ * FIXME: use cmdvartab for conformance checking
  * ...
  * Once the driver is loaded:
  * - change the value by using upsrw
@@ -36,7 +37,7 @@
 /* --------------------------------------------------------------- */
 
 typedef struct {
-	char	*status_str;	/* ups.status string */
+	const char	*status_str;	/* ups.status string */
 	int	status_value;	/* ups.status value */
 } status_lkp_t;
 
@@ -81,11 +82,11 @@ typedef struct {
 /* --------------------------------------------------------------- */
 
 typedef struct {
-	char	*info_type;	/* NUT variable name */
+	const char	*info_type;	/* NUT variable name */
 	int	info_flags;	/* NUT flags (to set in addinfo) */
 	float	info_len;	/* if ST_FLAG_STRING: length of the string */
 				/* if HU_TYPE_CMD: command value ; multiplier (or max len) otherwise */
-	char	*default_value;	/* if HU_FLAG_ABSENT: default value ; format otherwise */
+	const char	*default_value;	/* if HU_FLAG_ABSENT: default value ; format otherwise */
 	int	drv_flags;	/* */
 	char	**var_values;	/* all possible values for this variable (allows to check data...) */
 				/* FIXME: "void *" so we can have bound or enum */
