@@ -40,7 +40,7 @@
 #include <sys/file.h>
 
 #include "parseconf.h"
-#include "ctype.h"
+#include "nut_ctype.h"
 #include "upstype.h"
 
 #define NUT_NET_ANSWER_MAX SMALLBUF
@@ -48,14 +48,14 @@
 /* prototypes from upsd.c */
 
 upstype_t *get_ups_ptr(const char *upsname);
-int ups_available(const upstype_t *ups, ctype_t *client);
+int ups_available(const upstype_t *ups, nut_ctype_t *client);
 
 void listen_add(const char *addr, const char *port);
 
 void kick_login_clients(const char *upsname);
-int sendback(ctype_t *client, const char *fmt, ...)
+int sendback(nut_ctype_t *client, const char *fmt, ...)
 	__attribute__ ((__format__ (__printf__, 2, 3)));
-int send_err(ctype_t *client, const char *errtype);
+int send_err(nut_ctype_t *client, const char *errtype);
 
 void server_load(void);
 void server_free(void);
